@@ -1,4 +1,4 @@
 import os
 
 DB_HOME = os.environ.get('HOME')
-DB_DIR = f'{DB_HOME}/DB_OFX'
+DB_DIR = f'{DB_HOME}/ofxdb'
